@@ -53,8 +53,9 @@ use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
 use base qw( Exporter DynaLoader );
 
 BEGIN {
-  $VERSION = "2.00";
+  $VERSION = "2.01";
   bootstrap Net::BGPdump $VERSION;
+  __PACKAGE__->log_to_stderr(1);
 }
 
 ###
@@ -101,6 +102,13 @@ my @Constants = qw(
   BGPDUMP_SUBTYPE_ZEBRA_BGP_STATE_CHANGE
   BGPDUMP_SUBTYPE_ZEBRA_BGP_STATE_CHANGE_AS4
 
+  BGP_STATE_IDLE
+  BGP_STATE_CONNECT
+  BGP_STATE_ACTIVE
+  BGP_STATE_OPENSENT
+  BGP_STATE_OPENCONFIRM
+  BGP_STATE_ESTABLISHED
+
   BGP_MSG_UPDATE
   BGP_MSG_OPEN
   BGP_MSG_NOTIFY
@@ -134,6 +142,8 @@ my %Defaults = (
   exclude_subtype => -1,
   exclude_msgtype => -1,
   ipv6            => -1,
+  begin_time      => 0,
+  end_time        => 0,
 );
 
 my %Attr;
@@ -171,10 +181,22 @@ sub read {
     $attr->{exclude_subtype},
     $attr->{exclude_msgtype},
     $attr->{ipv6},
+    $attr->{begin_time},
+    $attr->{end_time},
   );
-  return () unless $entry;
-  $entry->{community} && $entry->{community} =~ s/^\s+//;
-  $entry;
+  $entry || ();
+}
+
+sub read_msg {
+  my $self = shift;
+  my $attr = $Attr{$self};
+  my $entry = filter_message_read(
+    $self,
+    $attr->{ipv6},
+    $attr->{begin_time},
+    $attr->{end_time},
+  );
+  $entry || ();
 }
 
 ###
@@ -311,8 +333,18 @@ Include or exclude messages of the following types:
 
 Include or exclude records involving IPv6 using 1 or 0, respectively.
 
+=item begin_time
+
+=item end_time
+
+Exclude records with timestamps < begin_time or >= end_time.
+
 =back
 
+B<Note:> opening and handling more than one table dump file (as opposed
+to update files) will likely cause problems. See the BUGS section below
+for more information.
+
 =item close()
 
 Close the C<Net::BGPdump> IO object.
@@ -322,6 +354,13 @@ Close the C<Net::BGPdump> IO object.
 Return the next record as a hash reference. Records are possibly subject
 to filtering as specified in the C<open()> constructor.
 
+=item read_msg()
+
+Return the next update record as a hash reference. This limits records
+to either MRTD or ZEBRA messages and discards things such as keepalive
+records.  Records are possibly subject to filtering on ipv6 or time as
+specified in the C<open()> constructor.
+
 =item closed()
 
 Return whether or not the file has been closed.
@@ -357,6 +396,31 @@ Return the number of records successfully poarsed so far.
 
 IO objects can be used as filehandles, so C<E<lt>$ioE<gt>> works as expected.
 
+=head1 ADDITIONAL CONSTANTS
+
+The following constants can also be exported:
+
+  BGP_STATE_IDLE
+  BGP_STATE_CONNECT
+  BGP_STATE_ACTIVE
+  BGP_STATE_OPENSENT
+  BGP_STATE_OPENCONFIRM
+  BGP_STATE_ESTABLISHED
+
+=head1 BUGS
+
+* Opening and reading more than one table dump file (as opposed to mere
+  update files) will likely cause a segfault since libbgpdump uses a
+  single global index table each time a file of that type is opened and
+  frees the structure whenever one of the files is closed, even if the
+  other one is still using the index table.
+
+* Corrupt files will cause perl to silently abort when a bad record
+  is encountered and cannot be caught using eval(). This happens when
+  libbgpdump attempts to call the err() function -- there is some sort
+  of name collision with the perl library. Until this is fixed, files
+  must unfortunately be checked ahead of time with gunzip or bunzip2.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright (C) 2015 by Carnegie Mellon University
